@@ -62,9 +62,7 @@ fn extract_symbol<'a>(
         ref exprs,
         ref quasis,
         ..
-      }) if exprs.is_empty() && quasis.len() == 1 => {
-        Some(quasis[0].raw.value())
-      }
+      }) if exprs.is_empty() && quasis.len() == 1 => Some(quasis[0].raw()),
       _ => None,
     },
   }
