@@ -1,8 +1,4 @@
 // Copyright 2020-2021 the Deno authors. All rights reserved. MIT license.
-use crate::scopes::BindingKind;
-use derive_more::Display;
-use std::sync::Arc;
-
 use super::{Context, LintRule};
 use crate::handler::{Handler, Traverse};
 use crate::{Program, ProgramRef};
@@ -11,6 +7,9 @@ use deno_ast::swc::common::Spanned;
 use deno_ast::view::{
   ArrayPat, AssignExpr, Expr, Ident, ObjectPat, ObjectPatProp, Pat, PatOrExpr,
 };
+use deno_ast::BindingKind;
+use derive_more::Display;
+use std::sync::Arc;
 
 #[derive(Debug)]
 pub struct NoExAssign;
