@@ -2,8 +2,8 @@
 use super::{Context, LintRule};
 use crate::ProgramRef;
 use deno_ast::swc::ast::{
-  ArrowExpr, CallExpr, ClassProp, Expr, Function, Ident, Lit, NewExpr,
-  OptChainExpr, Pat, PrivateProp, TsEntityName, TsKeywordType,
+  ArrowExpr, CallExpr, ClassProp, Expr, Function, Ident, Lit, NewExpr, OptCall,
+  OptChainBase, OptChainExpr, Pat, PrivateProp, TsEntityName, TsKeywordType,
   TsKeywordTypeKind, TsType, TsTypeAnn, TsTypeRef, UnaryExpr, VarDecl,
 };
 use deno_ast::swc::ast::{Callee, PropName};
@@ -79,11 +79,15 @@ impl<'c, 'view> NoInferrableTypesVisitor<'c, 'view> {
   }
 
   fn check_callee(&mut self, callee: &Callee, span: Span, expected_sym: &str) {
-    if let Callee::Expr(unboxed) = &callee {
-      if let Expr::Ident(value) = &**unboxed {
-        if value.sym == *expected_sym {
-          self.add_diagnostic_helper(span);
-        }
+    if let Callee::Expr(expr) = &callee {
+      self.check_callee_expr(expr, span, expected_sym);
+    }
+  }
+
+  fn check_callee_expr(&mut self, expr: &Expr, span: Span, expected_sym: &str) {
+    if let Expr::Ident(value) = expr {
+      if value.sym == *expected_sym {
+        self.add_diagnostic_helper(span);
       }
     }
   }
@@ -114,17 +118,19 @@ impl<'c, 'view> NoInferrableTypesVisitor<'c, 'view> {
           Expr::Call(CallExpr { callee, .. }) => {
             self.check_callee(callee, span, "BigInt");
           }
-          Expr::OptChain(OptChainExpr { expr, .. }) => {
-            if let Expr::Call(CallExpr { callee, .. }) = &**expr {
-              self.check_callee(callee, span, "BigInt");
-            }
+          Expr::OptChain(OptChainExpr {
+            base: OptChainBase::Call(OptCall { callee, .. }),
+            ..
+          }) => {
+            self.check_callee_expr(callee, span, "BigInt");
           }
           _ => {}
         },
-        Expr::OptChain(OptChainExpr { expr, .. }) => {
-          if let Expr::Call(CallExpr { callee, .. }) = &**expr {
-            self.check_callee(callee, span, "BigInt");
-          }
+        Expr::OptChain(OptChainExpr {
+          base: OptChainBase::Call(OptCall { callee, .. }),
+          ..
+        }) => {
+          self.check_callee_expr(callee, span, "BigInt");
         }
         _ => {}
       },
@@ -140,10 +146,11 @@ impl<'c, 'view> NoInferrableTypesVisitor<'c, 'view> {
             self.add_diagnostic_helper(span);
           }
         }
-        Expr::OptChain(OptChainExpr { expr, .. }) => {
-          if let Expr::Call(CallExpr { callee, .. }) = &**expr {
-            self.check_callee(callee, span, "Boolean");
-          }
+        Expr::OptChain(OptChainExpr {
+          base: OptChainBase::Call(OptCall { callee, .. }),
+          ..
+        }) => {
+          self.check_callee_expr(callee, span, "Boolean");
         }
         _ => {}
       },
@@ -171,17 +178,19 @@ impl<'c, 'view> NoInferrableTypesVisitor<'c, 'view> {
               self.add_diagnostic_helper(span);
             }
           }
-          Expr::OptChain(OptChainExpr { expr, .. }) => {
-            if let Expr::Call(CallExpr { callee, .. }) = &**expr {
-              self.check_callee(callee, span, "Number");
-            }
+          Expr::OptChain(OptChainExpr {
+            base: OptChainBase::Call(OptCall { callee, .. }),
+            ..
+          }) => {
+            self.check_callee_expr(callee, span, "Number");
           }
           _ => {}
         },
-        Expr::OptChain(OptChainExpr { expr, .. }) => {
-          if let Expr::Call(CallExpr { callee, .. }) = &**expr {
-            self.check_callee(callee, span, "Number");
-          }
+        Expr::OptChain(OptChainExpr {
+          base: OptChainBase::Call(OptCall { callee, .. }),
+          ..
+        }) => {
+          self.check_callee_expr(callee, span, "Number");
         }
         _ => {}
       },
@@ -200,20 +209,23 @@ impl<'c, 'view> NoInferrableTypesVisitor<'c, 'view> {
         Expr::Call(CallExpr { callee, .. }) => {
           self.check_callee(callee, span, "String");
         }
-        Expr::OptChain(OptChainExpr { expr, .. }) => {
-          if let Expr::Call(CallExpr { callee, .. }) = &**expr {
-            self.check_callee(callee, span, "String");
-          }
+        Expr::OptChain(OptChainExpr {
+          base: OptChainBase::Call(OptCall { callee, .. }),
+          ..
+        }) => {
+          self.check_callee_expr(callee, span, "String");
         }
         _ => {}
       },
       TsSymbolKeyword => {
         if let Expr::Call(CallExpr { callee, .. }) = &*value {
           self.check_callee(callee, span, "Symbol");
-        } else if let Expr::OptChain(OptChainExpr { expr, .. }) = &*value {
-          if let Expr::Call(CallExpr { callee, .. }) = &**expr {
-            self.check_callee(callee, span, "Symbol");
-          }
+        } else if let Expr::OptChain(OptChainExpr {
+          base: OptChainBase::Call(OptCall { callee, .. }),
+          ..
+        }) = &*value
+        {
+          self.check_callee_expr(callee, span, "Symbol");
         }
       }
       TsUndefinedKeyword => match &*value {
@@ -250,16 +262,18 @@ impl<'c, 'view> NoInferrableTypesVisitor<'c, 'view> {
             if ident.sym == *"RegExp" {
               self.add_diagnostic_helper(span);
             }
-          } else if let Expr::OptChain(OptChainExpr { expr, .. }) = &**callee {
-            if let Expr::Call(CallExpr { callee, .. }) = &**expr {
-              self.check_callee(callee, span, "RegExp");
+          } else if let Expr::OptChain(opt_chain) = &**callee {
+            if let OptChainBase::Call(OptCall { callee, .. }) = &opt_chain.base
+            {
+              self.check_callee_expr(callee, span, "RegExp");
             }
           }
         }
-        Expr::OptChain(OptChainExpr { expr, .. }) => {
-          if let Expr::Call(CallExpr { callee, .. }) = &**expr {
-            self.check_callee(callee, span, "RegExp");
-          }
+        Expr::OptChain(OptChainExpr {
+          base: OptChainBase::Call(OptCall { callee, .. }),
+          ..
+        }) => {
+          self.check_callee_expr(callee, span, "RegExp");
         }
         _ => {}
       }
